Discover Packages
github.com/vertexdlt/vertexvm
number
package
Version:
v0.0.0-...-9094145
Opens a new window with list of versions in this module.
Published: Jan 21, 2021
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
func CanTruncate(from Type , to Type , value interface{}) bool
CanTruncate checks if a float (from) can be converted to an int (to)
FloatTruncate truncates a float represented by floatBits to an integer (signed or unsigned)
when it cannot perform the operation it returns the corresponding trap codes
const (
I32 Type = iota
U32
I64
U64
F32
F64
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.